==> freecell-solver-2.14.0.tar.gz: freecell-solver-2.14.0/Presets/presets/cmake_install.cmake <==
# Install script for directory: /home/shlomi/progs/freecell/trunk/fc-solve/source/Presets/presets

# Set the install prefix
IF(NOT DEFINED CMAKE_INSTALL_PREFIX)
  SET(CMAKE_INSTALL_PREFIX "/home/shlomi/apps/test/fcs")
ENDIF(NOT DEFINED CMAKE_INSTALL_PREFIX)
STRING(REGEX REPLACE "/$" "" CMAKE_INSTALL_PREFIX "${CMAKE_INSTALL_PREFIX}")

# Set the install configuration name.
IF(NOT DEFINED CMAKE_INSTALL_CONFIG_NAME)
  IF(BUILD_TYPE)
    STRING(REGEX REPLACE "^[^A-Za-z0-9_]+" ""
           CMAKE_INSTALL_CONFIG_NAME "${BUILD_TYPE}")
  ELSE(BUILD_TYPE)
    SET(CMAKE_INSTALL_CONFIG_NAME "release")
  ENDIF(BUILD_TYPE)
  MESSAGE(STATUS "Install configuration: \"${CMAKE_INSTALL_CONFIG_NAME}\"")
ENDIF(NOT DEFINED CMAKE_INSTALL_CONFIG_NAME)

# Set the component getting installed.
IF(NOT CMAKE_INSTALL_COMPONENT)
  IF(COMPONENT)
    MESSAGE(STATUS "Install component: \"${COMPONENT}\"")
    SET(CMAKE_INSTALL_COMPONENT "${COMPONENT}")
  ELSE(COMPONENT)
    SET(CMAKE_INSTALL_COMPONENT)
  ENDIF(COMPONENT)
ENDIF(NOT CMAKE_INSTALL_COMPONENT)

# Install shared libraries without execute permission?
IF(NOT DEFINED CMAKE_INSTALL_SO_NO_EXE)
  SET(CMAKE_INSTALL_SO_NO_EXE "0")
ENDIF(NOT DEFINED CMAKE_INSTALL_SO_NO_EXE)

IF(NOT CMAKE_INSTALL_COMPONENT OR "${CMAKE_INSTALL_COMPONENT}" STREQUAL "Unspecified")
  FILE(INSTALL DESTINATION "/home/shlomi/apps/test/fcs/share/freecell-solver/presets" TYPE FILE FILES
    "/home/shlomi/progs/freecell/trunk/fc-solve/source/Presets/presets/abra-kadabra.sh"
    "/home/shlomi/progs/freecell/trunk/fc-solve/source/Presets/presets/cool-jives.sh"
    "/home/shlomi/progs/freecell/trunk/fc-solve/source/Presets/presets/crooked-nose.sh"
    "/home/shlomi/progs/freecell/trunk/fc-solve/source/Presets/presets/fools-gold.sh"
    "/home/shlomi/progs/freecell/trunk/fc-solve/source/Presets/presets/hello-world.sh"
    "/home/shlomi/progs/freecell/trunk/fc-solve/source/Presets/presets/john_galt_line-500.sh"
    "/home/shlomi/progs/freecell/trunk/fc-solve/source/Presets/presets/rin-tin-tin.sh"
    "/home/shlomi/progs/freecell/trunk/fc-solve/source/Presets/presets/yellow-brick-road.sh"
    )
ENDIF(NOT CMAKE_INSTALL_COMPONENT OR "${CMAKE_INSTALL_COMPONENT}" STREQUAL "Unspecified")

==> freecell-solver-2.22.0.tar.gz: freecell-solver-2.22.0/Presets/presets/cmake_install.cmake <==
# Install script for directory: /home/shlomi/progs/freecell/trunk/fc-solve/source/Presets/presets

# Set the install prefix
IF(NOT DEFINED CMAKE_INSTALL_PREFIX)
  SET(CMAKE_INSTALL_PREFIX "/usr")
ENDIF(NOT DEFINED CMAKE_INSTALL_PREFIX)
STRING(REGEX REPLACE "/$" "" CMAKE_INSTALL_PREFIX "${CMAKE_INSTALL_PREFIX}")

# Set the install configuration name.
IF(NOT DEFINED CMAKE_INSTALL_CONFIG_NAME)
  IF(BUILD_TYPE)
    STRING(REGEX REPLACE "^[^A-Za-z0-9_]+" ""
           CMAKE_INSTALL_CONFIG_NAME "${BUILD_TYPE}")
  ELSE(BUILD_TYPE)
    SET(CMAKE_INSTALL_CONFIG_NAME "debug")
  ENDIF(BUILD_TYPE)
  MESSAGE(STATUS "Install configuration: \"${CMAKE_INSTALL_CONFIG_NAME}\"")
ENDIF(NOT DEFINED CMAKE_INSTALL_CONFIG_NAME)

# Set the component getting installed.
IF(NOT CMAKE_INSTALL_COMPONENT)
  IF(COMPONENT)
    MESSAGE(STATUS "Install component: \"${COMPONENT}\"")
    SET(CMAKE_INSTALL_COMPONENT "${COMPONENT}")
  ELSE(COMPONENT)
    SET(CMAKE_INSTALL_COMPONENT)
  ENDIF(COMPONENT)
ENDIF(NOT CMAKE_INSTALL_COMPONENT)

# Install shared libraries without execute permission?
IF(NOT DEFINED CMAKE_INSTALL_SO_NO_EXE)
  SET(CMAKE_INSTALL_SO_NO_EXE "0")
ENDIF(NOT DEFINED CMAKE_INSTALL_SO_NO_EXE)

IF(NOT CMAKE_INSTALL_COMPONENT OR "${CMAKE_INSTALL_COMPONENT}" STREQUAL "Unspecified")
  FILE(INSTALL DESTINATION "/usr/share/freecell-solver/presets" TYPE FILE FILES
    "/home/shlomi/progs/freecell/trunk/fc-solve/source/Presets/presets/abra-kadabra.sh"
    "/home/shlomi/progs/freecell/trunk/fc-solve/source/Presets/presets/cool-jives.sh"
    "/home/shlomi/progs/freecell/trunk/fc-solve/source/Presets/presets/crooked-nose.sh"
    "/home/shlomi/progs/freecell/trunk/fc-solve/source/Presets/presets/fools-gold.sh"
    "/home/shlomi/progs/freecell/trunk/fc-solve/source/Presets/presets/hello-world.sh"
    "/home/shlomi/progs/freecell/trunk/fc-solve/source/Presets/presets/john_galt_line-500.sh"
    "/home/shlomi/progs/freecell/trunk/fc-solve/source/Presets/presets/rin-tin-tin.sh"
    "/home/shlomi/progs/freecell/trunk/fc-solve/source/Presets/presets/yellow-brick-road.sh"
    )
ENDIF(NOT CMAKE_INSTALL_COMPONENT OR "${CMAKE_INSTALL_COMPONENT}" STREQUAL "Unspecified")
